@@ -104,59 +104,6 @@ class QueryOp(type):
         return "QueryOp"
 
 
-@dataclass
-class QAP:
-    """Query argument placeholder (QAP) class.
-
-    Parameters
-    ----------
-    kwarg_name: str
-        Name of keyword argument for which this classs
-        acts as a placeholder.
-    required: bool
-        Whether the keyword argument is required to run the process.
-    transform_fn: callable
-        A function accepting and transforming the passed in argument.
-
-    """
-
-    kwarg_name: str
-    required: bool = True
-    transform_fn: Optional[Callable] = None
-
-    def __repr__(self):
-        """Return the name of the placeholded keyword argument.
-
-        Returns
-        -------
-        str
-            The name of the keyword argument.
-
-        """
-        return self.kwarg_name
-
-    def __call__(self, **kwargs):
-        """Recover the value of the placeholder argument.
-
-        Parameters
-        ----------
-        **kwargs: Any
-            kwarg which corresponds to self.kwarg_name as a key with a
-            corresponding value.
-
-        Returns
-        -------
-        any
-            Value of the placeholder argument.
-
-        """
-        val = kwargs[self.kwarg_name]
-        if self.transform_fn is not None:
-            return self.transform_fn(val)
-
-        return val
-
-
 def _chain_ops(query, ops):
     if isinstance(ops, List):
         for op_ in ops:
@@ -203,129 +150,6 @@ class Sequential:
         return _chain_ops(table, self.ops)
 
 
-@table_params_to_type(Subquery)
-def process_operations(  # pylint: disable=too-many-locals
-    table: TableTypes, operations: List[tuple], user_kwargs: dict
-) -> Subquery:
-    """Query MIMIC encounter-specific patient data.
-
-    Parameters
-    ----------
-    table: cyclops.query.util.TableTypes
-        Table to process.
-    operations:
-        Operations to execute, which are of the form:
-        (process function, arguments to pass, keyword arguments to pass).
-    user_kwargs:
-        Keyword arguments specified by the calling function, or user.
-        If a keyword argument is None, it is discarded.
-
-    Returns
-    -------
-    cyclops.query.interface.QueryInterface
-        Constructed query, wrapped in an interface object.
-
-    """
-    # Remove None user kwargs
-    user_kwargs = {
-        kwarg: value for kwarg, value in user_kwargs.items() if value is not None
-    }
-
-    def get_required_qap(qaps):
-        return [qap for qap in qaps if qap.required]
-
-    def get_qap_args(operation, required=False):
-        qap_args = [arg for arg in operation[1] if isinstance(arg, QAP)]
-        if required:
-            qap_args = get_required_qap(qap_args)
-        return qap_args
-
-    def get_qap_kwargs(operation, required=False):
-        qap_kwargs = [val for _, val in operation[2].items() if isinstance(val, QAP)]
-        if required:
-            qap_kwargs = get_required_qap(qap_kwargs)
-        return qap_kwargs
-
-    def process_args(args):
-        return [arg(**user_kwargs) if isinstance(arg, QAP) else arg for arg in args]
-
-    def process_kwargs(kwargs):
-        for key, value in kwargs.items():
-            if isinstance(value, QAP):
-                # Convert if found
-                if str(value) in user_kwargs:
-                    kwargs[key] = value(user_kwargs)
-                # Otherwise, ensure it wasn't required and remove later
-                else:
-                    if value.required:
-                        raise ValueError(f"QAP {str(value)} must be specified.")
-
-        # Remove optional kwargs which were not specified
-        kwargs = {
-            key: value for key, value in kwargs.items() if not isinstance(value, QAP)
-        }
-
-        return kwargs
-
-    def flatten_2d(lst):
-        return [j for sub in lst for j in sub]
-
-    # Get the valid kwargs which may be specified for this function
-    qap_args = flatten_2d([get_qap_args(op) for op in operations])
-    qap_kwargs = flatten_2d([get_qap_kwargs(op) for op in operations])
-    kwargs_supported = [str(qap) for qap in qap_args + qap_kwargs]
-
-    # Ensure only supported operations are being performed
-    for kwarg in user_kwargs:
-        if kwarg not in kwargs_supported:
-            raise ValueError(
-                f"""Keyword {kwarg} is not supported in this query function,
-                only keywords {', '.join(kwargs_supported)}"""
-            )
-
-    for operation in operations:
-        process_func, args, kwargs = operation
-
-        # Skip if not all the required kwargs were given
-        required = get_qap_args(operation, required=True) + get_qap_kwargs(
-            operation, required=True
-        )
-        specified_required = [str(r) in list(user_kwargs.keys()) for r in required]
-
-        if not all(specified_required):
-            # If not all the required parameters are specified ones, warn if only
-            # some of the parameters are.
-            all_params = get_qap_args(operation, required=False) + get_qap_kwargs(
-                operation, required=False
-            )
-            specified_params = [str(r) in list(user_kwargs.keys()) for r in all_params]
-            if any(specified_params):
-                specified_kwargs = [
-                    str(kwarg)
-                    for i, kwarg in enumerate(all_params)
-                    if specified_params[i]
-                ]
-                missing_kwargs = [
-                    str(kwarg)
-                    for i, kwarg in enumerate(required)
-                    if not specified_required[i]
-                ]
-                raise ValueError(
-                    f"""Process arguments {', '.join(specified_kwargs)} were
-                    specified, but missing {', '.join(missing_kwargs)}"""
-                )
-
-            continue
-
-        # Run the operation, replacing all the query argument placeholders with
-        # their respective values
-        args = process_args(args)
-        kwargs = process_kwargs(kwargs)
-        table = process_func(*args, **kwargs)(table)
-
-    return table
-
-
 def _append_if_missing(
     table: TableTypes,
     keep_cols: Optional[Union[str, List[str]]] = None,
